Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Program ¶
type Program struct {
// contains filtered or unexported fields
}
func Compile ¶
Compile compiles a sed script and returns a program upon successfull compilation. If unsuccessfull errors are returned.
func MustCompile ¶
MustCompile takes a sed script and compiles it into a program. Panics if errors are found in script.
func (*Program) FilterA ¶
FilterA performs a normal filter operation but does not reset the state after completion. You can repeatedly call FilterA to process input line by line.
func (*Program) FilterString ¶
func (*Program) FilterStringA ¶
FilterStringA performs a normal filter operation but does not reset the state after completion. Operation is performed on string and returns a string. You can repeatedly call FilterA to process input line by line.
Click to show internal directories.
Click to hide internal directories.